# gsvdm2py
A Python wrapper for MATLAB's gsvd function (generalized singular value decomposition).

Installation instructions:

1. Make sure MATLAB is installed.

2. pip install matlabengine.

3. pip install gsvdm2py





